from rocolib.api.components import FoldedComponent
from rocolib.api.composables.graph.Face import Face, Rectangle
import rocolib.utils.numsym as np


class SimpleUChannel(FoldedComponent):
  def define(self):
    self.addParameter("length", 100, paramType="length")
    self.addParameter("width", 50, paramType="length")
    self.addParameter("depth", 20, paramType="length")

    for i in range(3):
      self.addEdgeInterface("topedge%d" % i, "r%d.e0" % i, ["depth", "width"][i % 2])
      self.addEdgeInterface("botedge%d" % i, "r%d.e2" % i, ["depth", "width"][i % 2])
      self.addFaceInterface("face%d" % i, "r%d" % i)

    self.addEdgeInterface("ledge", "r0.e3", "length")
    self.addEdgeInterface("redge", "r2.e1", "length")

    self.addEdgeInterface("top", ["r%d.e0" % i for i in range(3)], ["depth", "width", "depth"])
    self.addEdgeInterface("bot", ["r%d.e2" % (2-i) for i in range(3)], ["depth", "width", "depth"])

  def assemble(self):
    length = self.getParameter("length")
    width = self.getParameter("width")
    depth = self.getParameter("depth")

    rs = []
    rs.append(Rectangle("", depth, length))
    rs.append(Rectangle("", width, length))
    rs.append(Rectangle("", depth, length))

    fromEdge = None
    for i in range(3):
      self.attachEdge(fromEdge, rs[i], "e3", prefix="r%d"%i, angle=90, root=(i==1))
      fromEdge = 'r%d.e1' % i


if __name__ == "__main__":
  SimpleUChannel.test()

  #test transform3D
  r = SimpleUChannel()
  r.makeOutput(transform3D=[[1,0,0,0],[0,-1,0,0],[0,0,-1,0],[0,0,0,1]], default=False)
  g = r.getGraph()
  for f in g.faces:
    print ("########", f.name)
    print(f.get3DCoords())

  #test sympy
  r = SimpleUChannel()
  r.makeOutput(useDefaultParameters=False, default=False)
  g = r.getGraph()
  for f in g.faces:
    print ("########", f.name)
    #print(f.transform2D)
    #print(f.transform3D)
    #print(f.get2DCoords())
    np.pprint(f.get3DCoords())
